'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.formatTimespan = undefined;
exports.formatTime = formatTime;

var _formatMessage = require('quiz-common/lib/format-message');

var _formatMessage2 = _interopRequireDefault(_formatMessage);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var minuteDuration = 60;
var hourDuration = 3600;

var formatHours = function formatHours(hours) {
  return (0, _formatMessage2.default)('{ hours, plural, one {# hour} other {# hours} }', { hours: hours });
};

var formatMinutes = function formatMinutes(minutes) {
  return (0, _formatMessage2.default)('{ minutes, plural, one {# minute} other {# minutes} }', { minutes: minutes });
};

var formatSeconds = function formatSeconds(seconds) {
  return (0, _formatMessage2.default)('{ seconds, plural, one {# second} other {# seconds} }', { seconds: seconds });
};

var formatTimespan = exports.formatTimespan = function formatTimespan(startTime, endTime) {
  return formatTime(endTime - startTime, 1000);
};

function formatTime(time) {
  var secondDuration = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;

  var totalSeconds = Math.floor(time / secondDuration);
  var parts = [];

  var hours = Math.floor(totalSeconds / hourDuration);
  if (hours !== 0) {
    parts.push(formatHours(hours));
  }

  var minutes = Math.floor(totalSeconds / minuteDuration) % minuteDuration;
  if (minutes !== 0) {
    parts.push(formatMinutes(minutes));
  }

  var seconds = totalSeconds % minuteDuration;
  if (seconds !== 0 || parts.length === 0) {
    parts.push(formatSeconds(seconds));
  }

  var separator = (0, _formatMessage2.default)({
    id: 'timespan_segment_separator',
    default: ' ',
    description: 'The character(s) inserted between "5 minutes" and "30 seconds" in ' + 'a timespan string like "5 minutes 30 seconds"'
  });
  return parts.join(separator);
}