'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = undefined;

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _dec,
    _class,
    _class2,
    _temp2,
    _default_enIE_number = Intl.NumberFormat('en-IE', { style: 'decimal' }).format,
    _percent_enIE_number = Intl.NumberFormat('en-IE', { style: 'percent' }).format; /* eslint "import/no-extraneous-dependencies": "warn" */


// TODO change the d3 dependency in package.json to match specific modules


var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _d3Array = require('d3-array');

var _d3Axis = require('d3-axis');

var _d3Scale = require('d3-scale');

var _d3Selection = require('d3-selection');

var _lib = require('@instructure/ui-themeable/lib');

var _lib2 = _interopRequireDefault(_lib);

var _formatMessage = require('quiz-common/lib/format-message');

var _formatMessage2 = _interopRequireDefault(_formatMessage);

var _theme = require('./theme');

var _theme2 = _interopRequireDefault(_theme);

var _ScreenReaderContent = require('@instructure/ui-a11y/lib/components/ScreenReaderContent');

var _ScreenReaderContent2 = _interopRequireDefault(_ScreenReaderContent);

var _PresentationContent = require('@instructure/ui-a11y/lib/components/PresentationContent');

var _PresentationContent2 = _interopRequireDefault(_PresentationContent);

var _d3Transition = require('d3-transition');

var _flow = require('lodash/flow');

var _flow2 = _interopRequireDefault(_flow);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var styles = {
  template: function template(theme) {
    return '/*  imported from styles.css  */\n\n.Distribution__styles__bar {\n  fill: ' + theme.barFillColor + ';\n}\n\n.Distribution__styles__barContainer {\n}\n\n.Distribution__styles__xAxis {\n}\n\n.Distribution__styles__barLabel {\n  font-family: ' + theme.barLabelFontFamily + ';\n  font-size: ' + theme.barLabelFontSize + ';\n  text-anchor: middle;\n}\n';
  },
  'bar': 'Distribution__styles__bar',
  'barContainer': 'Distribution__styles__barContainer',
  'xAxis': 'Distribution__styles__xAxis',
  'barLabel': 'Distribution__styles__barLabel'
};

// TODO change the d3 dependency in package.json to match specific modules

var MARGIN_T = 0;
var MARGIN_B = 28;

/**
 *   A component to render an a11y friendly distribution of scores across users.
 *   Underneath the chart is two accessible features:
 *     1. A keyboard friendly set of min(10, bucketCounts) buckets {0-10%, 10-20%, ..., 90-100%}
 *     with the number of users in that slice
 *     2. A screenreader-only block of content providing a table version of all the data
 *
 *     ```jsx_example
 *      <Distribution
 *        summaryDistribution={Array.from({length: 10}, () => Math.floor(Math.random() * 5))}
 *        visualDistribution={Array.from({length: 101}, () => Math.floor(Math.random() * 5))}
 *      />
 *      ```
 *  **/
// TODO: Less inheritance, more composition...
var Distribution = (_dec = (0, _lib2.default)(_theme2.default, styles), _dec(_class = (_temp2 = _class2 = function (_Component) {
  (0, _inherits3.default)(Distribution, _Component);

  function Distribution() {
    var _ref;

    var _temp, _this, _ret;

    (0, _classCallCheck3.default)(this, Distribution);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = (0, _possibleConstructorReturn3.default)(this, (_ref = Distribution.__proto__ || Object.getPrototypeOf(Distribution)).call.apply(_ref, [this].concat(args))), _this), _this.applyTransition = function (selection, initialFunc, finalFunc, transitionFunc) {
      var identity = function identity(s) {
        return s;
      };
      var transition = function transition(s) {
        return s.transition(_this.getTransition());
      };

      var applicators = [];
      if (_this.isAnimated()) {
        applicators.push(initialFunc || identity, transition, transitionFunc || identity);
      }
      applicators.push(finalFunc || identity);

      return (0, _flow2.default)(applicators)(selection);
    }, _temp), (0, _possibleConstructorReturn3.default)(_this, _ret);
  }

  (0, _createClass3.default)(Distribution, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.__svg = this.createChart(this.chart, this.props);
      this.updateChart(this.__svg, this.props);
    }
  }, {
    key: 'shouldComponentUpdate',
    value: function shouldComponentUpdate(nextProps) {
      this.updateChart(this.__svg, nextProps);
      return false;
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      this.removeChart();
    }
  }, {
    key: 'isAnimated',
    value: function isAnimated() {
      return this.props.animateDelay || this.props.animateDuration;
    }
  }, {
    key: 'calculateAxis',
    value: function calculateAxis(props) {
      // the x scale is static since it will always represent the BucketCount
      // percentiles, so we can avoid recalculating it on every update:
      this.x = (0, _d3Scale.scaleBand)().rangeRound([0, this.width]).paddingInner(props.barPaddingInner).paddingOuter(props.barPaddingOuter).domain((0, _d3Array.range)(props.visualDistribution.length));

      var highest = (0, _d3Array.max)(props.visualDistribution);
      this.y = (0, _d3Scale.scaleLinear)().rangeRound([this.height, props.barPaddingTop]).domain([0, highest]);

      this.xAxis = (0, _d3Axis.axisBottom)(this.x).tickSize([0]).tickValues((0, _d3Array.range)(props.visualDistribution.length));

      this.props.calculateAxis(this.x, this.y, this.xAxis, this.height);
    }
  }, {
    key: 'weightedAvg',
    value: function weightedAvg(data) {
      var partitions = data.length - 1;
      var totalStudents = (0, _d3Array.sum)(data);
      var avg = data.reduce(function (total, count, index) {
        // Assumes even weight of scores across distribution
        var score = index / partitions;
        return total + score * count;
      }, 0.0) / totalStudents;

      var avgPartition = Math.floor(avg * partitions);
      return {
        avg: avg,
        aboveAvg: (0, _d3Array.sum)(data.slice(avgPartition)),
        belowAvg: (0, _d3Array.sum)(data.slice(0, avgPartition))
      };
    }
  }, {
    key: 'summarizeChart',
    value: function summarizeChart() {
      var data = this.props.summaryDistribution || this.props.visualDistribution;
      if (data.length <= 1) {
        return '';
      }
      var avgInfo = this.weightedAvg(data);
      if (avgInfo.belowAvg + avgInfo.aboveAvg < 1) {
        return '';
      }

      var textForScreenreaders = avgInfo.aboveAvg + ' students scored above or at the average, and ' + avgInfo.belowAvg + ' below. ';

      data.forEach(function (datum, i) {
        if (datum > 0) {
          var _s, _n, _i, _v;

          textForScreenreaders += (_s = datum, _n = +_s, (_i = Math.floor(Math.abs(+_s)), _v = (_s + '.').split('.')[1].length, _i === 1 && _v === 0 ? _default_enIE_number(datum) + ' student scored between ' + _percent_enIE_number(i / data.length) + ' and ' + _percent_enIE_number((i + 1) / data.length) + '. ' : _default_enIE_number(datum) + ' students scored between ' + _percent_enIE_number(i / data.length) + ' and ' + _percent_enIE_number((i + 1) / data.length) + '. '));
        }
      });

      return this.props.summarizeChart(textForScreenreaders);
    }
  }, {
    key: 'createChart',
    value: function createChart(node, props) {
      // parentNode for IE11
      var parentWidth = (node.parentElement || node.parentNode || {}).offsetWidth;
      this.width = props.chartWidth || parentWidth;
      this.height = props.chartHeight;
      this.viewportHeight = this.height + MARGIN_T + MARGIN_B;

      this.calculateAxis(props);

      var svg = (0, _d3Selection.select)(node).attr('role', 'document').attr('aria-role', 'document').attr('width', '100%').attr('height', '100%').attr('viewBox', '0 0 ' + this.width + ' ' + this.viewportHeight).attr('preserveAspectRatio', 'xMidYMax').append('g');

      this.title = Distribution.addTitle(svg, 'Score percentiles chart');

      svg.append('g').attr('class', styles.xAxis).attr('aria-hidden', true).attr('transform', 'translate(0,' + this.height + ')').call(this.xAxis).selectAll('text').attr('class', styles.barLabel).attr('y', 9);

      var clipKey = 'clipPath' + this.width + 'x' + this.height;
      var clipPath = svg.append('clipPath').attr('id', clipKey);
      clipPath.append('rect').attr('x', 0).attr('y', 0).attr('width', this.width).attr('height', this.height);

      var barContainer = svg.append('g').attr('class', styles.barContainer).attr('clip-path', 'url(#' + clipKey + ')');

      this.barContainer = barContainer;

      this.props.createChart(svg, this.width);

      return svg;
    }
  }, {
    key: 'updateChart',
    value: function updateChart(svg, props) {
      this.renderBars(this.barContainer, props, styles.bar);
      this.props.updateChart(svg, this.x, this.y, this.applyTransition, this.barContainer, this.height);
    }
  }, {
    key: 'removeChart',
    value: function removeChart() {
      if (this.__svg) {
        this.__svg.remove();
        delete this.__svg;
      }
    }
  }, {
    key: 'renderBars',
    value: function renderBars(node, props, barStyle) {
      this.chartData = props.visualDistribution;
      var height = this.height;
      var x = this.x;
      var y = this.y;

      var bars = node.selectAll('rect').data(this.chartData);
      var rects = bars.enter().append('rect').classed(barStyle, true).attr('x', function (d, i) {
        return x(i);
      }).attr('width', x.bandwidth());
      this.applyTransition(rects, function (rects) {
        return rects.attr('y', height).attr('height', 0);
      }, function (rects) {
        return rects.attr('y', y).attr('height', function (d) {
          return height - y(d);
        });
      });

      bars.exit().remove();

      this.props.renderBars(node);
    }
  }, {
    key: 'getTransition',
    value: function getTransition() {
      this.transition = this.transition || (0, _d3Transition.transition)().delay(this.props.animateDelay || 0).duration(this.props.animateDuration || 0);
      return this.transition;
    }
  }, {
    key: 'renderSummary',
    value: function renderSummary() {
      return _react2.default.createElement(
        _ScreenReaderContent2.default,
        null,
        this.summarizeChart()
      );
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var _props = this.props,
          chartWidth = _props.chartWidth,
          chartHeight = _props.chartHeight;

      var viewportHeight = chartHeight + MARGIN_T + MARGIN_B;

      // IE11 sizes svg elements incorrectly, so we render a canvas element to
      // layout space for the chart, then position the svg absolute on top of it.
      return _react2.default.createElement(
        'div',
        null,
        _react2.default.createElement(
          _PresentationContent2.default,
          { as: 'div' },
          _react2.default.createElement(
            'div',
            { style: { position: 'relative' } },
            _react2.default.createElement('canvas', {
              width: chartWidth,
              height: viewportHeight,
              style: { display: 'block', visibility: 'hidden' }
            }),
            _react2.default.createElement('svg', {
              ref: function ref(_ref2) {
                _this2.chart = _ref2;
              },
              style: { position: 'absolute', top: 0, left: 0 }
            })
          )
        ),
        this.renderSummary(),
        this.props.renderTable()
      );
    }
  }], [{
    key: 'addTitle',
    value: function addTitle(svg, title) {
      return svg.append('title').text(title);
    }
  }]);
  return Distribution;
}(_react.Component), _class2.displayName = 'Distribution', _class2.propTypes = {
  animateDelay: _propTypes.PropTypes.number,
  animateDuration: _propTypes.PropTypes.number,
  barPaddingInner: _propTypes.PropTypes.number, // Spacing between bars, so each is visible, could be accomplished by borders
  barPaddingOuter: _propTypes.PropTypes.number, // Spacing between bars, so each is visible, could be accomplished by borders
  barPaddingTop: _propTypes.PropTypes.number,
  chartHeight: _propTypes.PropTypes.number.isRequired, // Height in pixels
  chartWidth: _propTypes.PropTypes.number,
  /* *
   * * a fallback minimal distribution for tab-able, keyboard navigable buckets
   * * typically this will be ~ 10 buckets
   * */
  summaryDistribution: _propTypes.PropTypes.arrayOf(_propTypes.PropTypes.node),
  /* *
   * * A list of score values for each bucket.  Size of this array determines the number of buckets
   * */
  visualDistribution: _propTypes.PropTypes.arrayOf(_propTypes.PropTypes.node).isRequired,

  calculateAxis: _propTypes.PropTypes.func,
  createChart: _propTypes.PropTypes.func,
  renderBars: _propTypes.PropTypes.func,
  renderTable: _propTypes.PropTypes.func,
  summarizeChart: _propTypes.PropTypes.func,
  updateChart: _propTypes.PropTypes.func
}, _class2.defaultProps = {
  animateDelay: 200,
  animateDuration: 900,
  barPaddingInner: 0.25, // Spacing between bars, so each is visible, could be accomplished by borders
  barPaddingOuter: 0, // Spacing between bars, so each is visible, could be accomplished by borders
  barPaddingTop: 0, // Spacing between highest bar and top of chart, pixels
  chartHeight: 200, // Height in pixels
  chartWidth: null,
  visualDistribution: [],
  calculateAxis: Function.prototype,
  createChart: Function.prototype,
  renderBars: Function.prototype,
  renderTable: Function.prototype,
  summarizeChart: function summarizeChart(textForScreenreaders) {
    return textForScreenreaders;
  },
  updateChart: Function.prototype
}, _temp2)) || _class);
exports.default = Distribution;